{"title": "Tags", "path": "../", "tags": {"elcato": [0, 3], "blog": [0, 3], "orgmode": [0, 1, 2], "markup": [1, 2], "hosting": [3]}, "author": ["El Cato", "email - not set", "me.png", "Welcome to the docs for El Cato static block generator", [["Chat", "Matrix", "https://riot.im/app/#/room/#elcato:matrix.org"], ["Software", "GitLab", "https://gitlab.com/python-open-source-library-collection/elcato"]]]}